Exception list functionality, primarily provided by org.spdx.library.ListedLicenses.
Notes:
Exception list functionality, primarily provided by `org.spdx.library.ListedLicenses`. Notes: * The functions in this namespace support any case of identifier or AdditionRef, as per the SPDX case sensitivity rules in [SPDX Specification Annex B](https://spdx.github.io/spdx-spec/v3.0.2/annexes/spdx-license-expressions/#case-sensitivity)
(addition-ref addition-ref-var-section)(addition-ref document-ref-var-section addition-ref-var-section)Constructs an AdditionRef (as a String) from individual 'variable
section' Strings. Returns nil if addition-ref-var-section is blank, or
the resulting value is not a valid AdditionRef.
Constructs an AdditionRef (as a `String`) from individual 'variable section' `String`s. Returns `nil` if `addition-ref-var-section` is blank, or the resulting value is not a valid AdditionRef.
(addition-ref-map->string m)Turns map m representing an AdditionRef into a String, returning nil if
m is nil or the resulting value is not a valid AdditionRef.
Note:
string->addition-ref-map.Turns map `m` representing an AdditionRef into a `String`, returning `nil` if `m` is `nil` or the resulting value is not a valid AdditionRef. Note: * This fn is the inverse of [[string->addition-ref-map]].
(addition-ref? s)Is s (a String) a valid AdditionRef? See
SPDX Specification Annex B
for specifics.
Is `s` (a `String`) a valid AdditionRef? See [SPDX Specification Annex B](https://spdx.github.io/spdx-spec/v3.0.2/annexes/spdx-license-expressions/) for specifics.
(canonicalise s)Canonicalises s (an SPDX exception identifier or AdditionRef), by returning
it in its canonical case. Returns nil if s is nil or not a listed SPDX
exception identifier or AdditionRef.
Notes:
spdx.expressions/parse can be used for
that.Canonicalises `s` (an SPDX exception identifier or AdditionRef), by returning it in its canonical case. Returns `nil` if `s` is `nil` or not a listed SPDX exception identifier or AdditionRef. Notes: * This function does _not_ canonicalise a deprecated id to its non-deprecated equivalent, since some of those conversions result in an SPDX expression rather than an individual id. [[spdx.expressions/parse]] can be used for that.
(deprecated-id? id)Is id (a String) deprecated? Also returns false if id is not a
listed SPDX exception identifier.
See this SPDX FAQ item for details on what this means.
Is `id` (a `String`) deprecated? Also returns `false` if `id` is not a listed SPDX exception identifier. See [this SPDX FAQ item](https://github.com/spdx/license-list-XML/blob/main/DOCS/faq.md#what-does-it-mean-when-a-license-id-is-deprecated) for details on what this means.
(equivalent? s1 s2)Are s1 and s2 (Strings) equivalent SPDX exception identifiers or
AdditionRefs (i.e. taking the SPDX case sensitivity rules in SPDX
Annex B
into account)?
Are `s1` and `s2` (`String`s) equivalent SPDX exception identifiers or AdditionRefs (i.e. taking the SPDX case sensitivity rules in [SPDX Annex B](https://spdx.github.io/spdx-spec/v3.0.2/annexes/spdx-license-expressions/#case-sensitivity) into account)?
(id->info id)(id->info id
{:keys [include-large-text-values?]
:or {include-large-text-values? false}
:as opts})Returns SPDX exception list information for id (a String) as a map, or
nil if id is not a listed SPDX exception identifier.
opts are:
:include-large-text-values? (default false) - controls whether large
text values are included in the result or notReturns SPDX exception list information for `id` (a `String`) as a map, or `nil` if `id` is not a listed SPDX exception identifier. `opts` are: * `:include-large-text-values?` (default `false`) - controls whether large text values are included in the result or not
(init!)Initialises this namespace upon first call (and does nothing on subsequent
calls), returning nil. Consumers of this namespace are not required to call
this fn, as initialisation will occur implicitly anyway; it is provided to
allow explicit control of the cost of initialisation to callers who need it.
Note: this function may have a substantial performance cost.
Initialises this namespace upon first call (and does nothing on subsequent calls), returning `nil`. Consumers of this namespace are not required to call this fn, as initialisation will occur implicitly anyway; it is provided to allow explicit control of the cost of initialisation to callers who need it. Note: this function may have a substantial performance cost.
(listed-id? s)Is s (a String) one of the listed SPDX exception identifiers?
Is `s` (a `String`) one of the listed SPDX exception identifiers?
(non-deprecated-ids)(non-deprecated-ids ids)Returns the set of SPDX exception identifiers that identify current
(non-deprecated) exceptions, within the provided set of listed SPDX
exception identifiers or all listed identifiers when ids not
provided.
Returns the set of SPDX exception identifiers that identify current (non-deprecated) exceptions, within the provided set of listed SPDX exception identifiers or all listed identifiers when `ids` not provided.
(string->addition-ref-map s)Turns s (a String containing an AdditionRef) into a map representing
that same AdditionRef. Returns nil if s is nil or not a valid
AdditionRef.
Note:
addition-ref-map->string.Turns `s` (a `String` containing an AdditionRef) into a `map` representing that same AdditionRef. Returns `nil` if `s` is `nil` or not a valid AdditionRef. Note: * This fn is the inverse of [[addition-ref-map->string]].
(version)The version of the exception list (a String in major.minor(.patchlevel)
format).
Note: identical to spdx.identifiers/version.
The version of the exception list (a `String` in major.minor(.patchlevel) format). Note: identical to [[spdx.identifiers/version]].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |