spdx.impl.utils

Utility namespace. Note: this namespace is not part of the public API of clj-spdx and may change without notice.

Utility namespace. Note: this namespace is not part of the public API of
clj-spdx and may change without notice.
raw docstring

maximum-concurrencyclj

Maximum allowed virtual concurrency, based primarily on macOS' stingy default per-process file handle limits (10240).

Maximum allowed virtual concurrency, based primarily on macOS' stingy
default per-process file handle limits (10240).
sourceraw docstring

safe-lower-caseclj

(safe-lower-case s)

Because clojure.string is not nil tolerant. 🙄

Because clojure.string is not `nil` tolerant. 🙄
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries