Utility namespace. Note: this namespace is not part of the public API of clj-spdx and may change without notice.
Utility namespace. Note: this namespace is not part of the public API of clj-spdx and may change without notice.
Maximum allowed virtual concurrency, based primarily on macOS' stingy default per-process file handle limits (10240).
Maximum allowed virtual concurrency, based primarily on macOS' stingy default per-process file handle limits (10240).
(safe-lower-case s)Because clojure.string is not nil tolerant. 🙄
Because clojure.string is not `nil` tolerant. 🙄
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |